package sun.awt.datatransfer;

import java.awt.datatransfer.UnsupportedFlavorException;
import java.io.IOException;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;

public class TransferableProxy implements Transferable
{
    protected final Transferable transferable;
    protected final boolean isLocal;
    
    public TransferableProxy(Transferable transferable, boolean isLocal) {
        this.transferable = transferable;
        this.isLocal = isLocal;
    }
    
    @Override
    public DataFlavor[] getTransferDataFlavors() {
        return this.transferable.getTransferDataFlavors();
    }
    
    @Override
    public boolean isDataFlavorSupported(DataFlavor dataFlavor) {
        return this.transferable.isDataFlavorSupported(dataFlavor);
    }
    
    @Override
    public Object getTransferData(DataFlavor dataFlavor) throws UnsupportedFlavorException, IOException {
        Object obj = this.transferable.getTransferData(dataFlavor);
        if (obj != null && this.isLocal && dataFlavor.isFlavorSerializedObjectType()) {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            ClassLoaderObjectOutputStream classLoaderObjectOutputStream = new ClassLoaderObjectOutputStream(byteArrayOutputStream);
            classLoaderObjectOutputStream.writeObject(obj);
            ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(byteArrayOutputStream.toByteArray());
            try {
                obj = new ClassLoaderObjectInputStream(byteArrayInputStream, classLoaderObjectOutputStream.getClassLoaderMap()).readObject();
            }
            catch (ClassNotFoundException cause) {
                throw (IOException)new IOException().initCause(cause);
            }
        }
        return obj;
    }
}
